StrokeColorComponent

Trait StrokeColorComponent 

pub trait StrokeColorComponent {
    // Required methods
    fn get_stroke_color(&self) -> &Color;
    fn set_stroke_color(&mut self, color: Color);
}
This trait provides functions for getting and setting the stroke color of a node. This should be implemented by any node that has a stroke color.

Required Methods

fn get_stroke_color(&self) -> &Color

Get the stroke (border/outline) color of the node.

Returns
  • &Color - A reference to the border color of the node.
fn set_stroke_color(&mut self, color: Color)

Set the stroke (border/outline) color of the node.

Arguments
  • color: Color - The new border color of the node.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors